DbResponse class

A generic reponse for database methods

Annotations
  • @freezed

Constructors

DbResponse({required dynamic data, String? eTag})
Default constructor
const
factory

Properties

copyWith → $DbResponseCopyWith<DbResponse>
no setterinherited
data → dynamic
The data that was returned by the server.
no setterinherited
eTag → String?
An optional ETag of the data, if it was requested.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited